@@ -1,6 +1,6 @@
 use crate::internal_prelude::*;
 
-#[derive(Clone)]
+#[derive(Clone, Debug, Eq, Ord, PartialEq, PartialOrd, Hash)]
 pub struct GlobalEcho(pub(crate) Handle);
 
 /// Re-exported Synthizer `syz_EchoTapConfig` type.  Using this instead of a
@@ -13,7 +13,7 @@ impl GlobalEcho {
         wrap_constructor(|ud, cb| {
             let mut h = Default::default();
             check_error(unsafe {
-                syz_createGlobalEcho(&mut h, context.to_syz_handle(), ud, Some(cb))
+                syz_createGlobalEcho(&mut h, context.to_syz_handle(), null_mut(), ud, Some(cb))
             })?;
             Ok(GlobalEcho(Handle::new(h)))
         })
