@@ -95,6 +95,7 @@ mod direct_source;
 mod enums;
 mod errors;
 mod events;
+mod fast_sine_bank_generator;
 mod generator;
 mod global_echo;
 mod global_fdn_reverb;
@@ -124,6 +125,7 @@ pub use direct_source::*;
 pub use enums::*;
 pub use errors::*;
 pub use events::*;
+pub use fast_sine_bank_generator::*;
 pub use generator::*;
 pub use global_echo::*;
 pub use global_fdn_reverb::*;
