@@ -1,6 +1,6 @@
 use crate::internal_prelude::*;
 
-#[derive(Clone)]
+#[derive(Clone, Debug, Eq, Ord, PartialEq, PartialOrd, Hash)]
 pub struct NoiseGenerator(pub(crate) Handle);
 
 impl NoiseGenerator {
@@ -12,6 +12,7 @@ impl NoiseGenerator {
                     &mut h as *mut syz_Handle,
                     context.to_syz_handle(),
                     channels,
+                    null_mut(),
                     ud,
                     Some(cb),
                 )
@@ -21,7 +22,7 @@ impl NoiseGenerator {
     }
 
     generator_properties!();
-    enum_p!(NoiseType, SYZ_P_NOISE_TYPE, get_noise_type, set_noise_type);
+    enum_p!(NoiseType, SYZ_P_NOISE_TYPE, noise_type);
 
     object_common!();
     pausable_common!();
