@@ -3,7 +3,7 @@ use std::path::Path;
 
 use crate::internal_prelude::*;
 
-#[derive(Clone)]
+#[derive(Clone, Debug, Eq, Ord, PartialEq, PartialOrd, Hash)]
 pub struct StreamingGenerator(pub(crate) Handle);
 
 impl StreamingGenerator {
@@ -22,6 +22,7 @@ impl StreamingGenerator {
                     &mut h,
                     context.to_syz_handle(),
                     c_str.as_ptr(),
+                    null_mut(),
                     ud,
                     Some(cb),
                 )
@@ -41,6 +42,7 @@ impl StreamingGenerator {
                     &mut out as *mut syz_Handle,
                     context.to_syz_handle(),
                     sh,
+                    null_mut(),
                     ud,
                     Some(cb),
                 )
@@ -73,6 +75,7 @@ impl StreamingGenerator {
                     protocol_ptr as *const c_char,
                     path_ptr as *const c_char,
                     std::mem::transmute(param),
+                    null_mut(),
                     ud,
                     Some(cb),
                 )
@@ -82,12 +85,8 @@ impl StreamingGenerator {
     }
 
     generator_properties!();
-    bool_p!(SYZ_P_LOOPING, get_looping, set_looping);
-    double_p!(
-        SYZ_P_PLAYBACK_POSITION,
-        get_playback_position,
-        set_playback_position
-    );
+    bool_p!(SYZ_P_LOOPING, looping);
+    double_p!(SYZ_P_PLAYBACK_POSITION, playback_position);
 
     object_common!();
     pausable_common!();
